@@ -9,7 +9,7 @@ from nose.tools import assert_raises
 
 from numcodecs.checksum32 import CRC32, Adler32
 from numcodecs.tests.common import check_encode_decode, check_config, \
-    check_repr
+    check_repr, check_backwards_compatibility
 
 
 # mix of dtypes: integer, float, bool, string
@@ -46,3 +46,8 @@ def test_config():
 def test_repr():
     check_repr("CRC32()")
     check_repr("Adler32()")
+
+
+def test_backwards_compatibility():
+    check_backwards_compatibility(CRC32.codec_id, arrays, [CRC32()])
+    check_backwards_compatibility(Adler32.codec_id, arrays, [Adler32()])
