@@ -10,19 +10,23 @@ try:
 except ImportError:  # pragma: no cover
     raise nose.SkipTest("msgpack-python not available")
 
-from numcodecs.tests.common import check_config, check_repr, check_encode_decode_array, \
-    check_backwards_compatibility
+from numcodecs.tests.common import (check_config, check_repr, check_encode_decode_array,
+                                    check_backwards_compatibility, greetings)
 
 
 # object array with strings
 # object array with mix strings / nans
 # object array with mix of string, int, float
+# ...
 arrays = [
     np.array(['foo', 'bar', 'baz'] * 300, dtype=object),
     np.array([['foo', 'bar', np.nan]] * 300, dtype=object),
     np.array(['foo', 1.0, 2] * 300, dtype=object),
     np.arange(1000, dtype='i4'),
     np.array(['foo', 'bar', 'baz'] * 300),
+    np.array(['foo', ['bar', 1.0, 2], {'a': 'b', 'c': 42}] * 300, dtype=object),
+    np.array(greetings * 100),
+    np.array(greetings * 100, dtype=object),
 ]
 
 
